==> nile_api-0.2.1.tar.gz: nile_api-0.2.1/nile_api/api/developers/start_developer_google_o_auth.py <==
from typing import Any, Dict, Union

import httpx

from ...client import Client
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: Client,
    redirect_to: Union[Unset, None, str] = UNSET,
) -> Dict[str, Any]:
    url = "{}/auth/oauth/google".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {}
    params["redirect_to"] = redirect_to

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _build_response(*, response: httpx.Response) -> Response[Any]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=None,
    )


def sync_detailed(
    *,
    client: Client,
    redirect_to: Union[Unset, None, str] = UNSET,
) -> Response[Any]:
    """Starts the developer Google OAuth flow

    Args:
        redirect_to (Union[Unset, None, str]):

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        client=client,
        redirect_to=redirect_to,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


async def asyncio_detailed(
    *,
    client: Client,
    redirect_to: Union[Unset, None, str] = UNSET,
) -> Response[Any]:
    """Starts the developer Google OAuth flow

    Args:
        redirect_to (Union[Unset, None, str]):

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        client=client,
        redirect_to=redirect_to,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)

==> nile_api-0.2.6.tar.gz: nile_api-0.2.6/nile_api/api/developers/start_developer_google_o_auth.py <==
from typing import Any, Dict, Union

import httpx

from ...client import Client
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: Client,
    redirect_to: Union[Unset, None, str] = UNSET,
) -> Dict[str, Any]:
    url = "{}/auth/oauth/google".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {}
    params["redirect_to"] = redirect_to

    params = {
        k: v for k, v in params.items() if v is not UNSET and v is not None
    }

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _build_response(*, response: httpx.Response) -> Response[Any]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=None,
    )


def sync_detailed(
    *,
    client: Client,
    redirect_to: Union[Unset, None, str] = UNSET,
) -> Response[Any]:
    """Start the developer Google OAuth flow

    Args:
        redirect_to (Union[Unset, None, str]):

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        client=client,
        redirect_to=redirect_to,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


async def asyncio_detailed(
    *,
    client: Client,
    redirect_to: Union[Unset, None, str] = UNSET,
) -> Response[Any]:
    """Start the developer Google OAuth flow

    Args:
        redirect_to (Union[Unset, None, str]):

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        client=client,
        redirect_to=redirect_to,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)
